==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_entities/workorderpart_001/WorkOrderPart.java <==

package net.datastream.schemas.mp_entities.workorderpart_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.PARTID_Type;
import net.datastream.schemas.mp_fields.STOREID_Type;
import net.datastream.schemas.mp_fields.WORKORDERPARTID;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERPARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBSEQUENCE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOREID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PLANNEDPARTQUANTITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RESERVEDPARTQUANTITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ALLOCATEDPARTQUANTITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTCONDITIONTEMPLATECONDITIONCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RETURNCONDITIONCODE" minOccurs="0"/>
 *         &lt;element name="DIRECT" type="{http://schemas.datastream.net/MP_fields}FLAG_Type"/>
 *       &lt;/sequence>
 *       &lt;attribute name="mlp_recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *       &lt;attribute name="res_recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "workorderpartid",
    "jobsequence",
    "partid",
    "storeid",
    "plannedpartquantity",
    "reservedpartquantity",
    "allocatedpartquantity",
    "partconditiontemplateconditioncode",
    "returnconditioncode",
    "direct"
})
@XmlRootElement(name = "WorkOrderPart")
public class WorkOrderPart {

    @XmlElement(name = "WORKORDERPARTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected WORKORDERPARTID workorderpartid;
    @XmlElement(name = "JOBSEQUENCE", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long jobsequence;
    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected PARTID_Type partid;
    @XmlElement(name = "STOREID", namespace = "http://schemas.datastream.net/MP_fields")
    protected STOREID_Type storeid;
    @XmlElement(name = "PLANNEDPARTQUANTITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY plannedpartquantity;
    @XmlElement(name = "RESERVEDPARTQUANTITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY reservedpartquantity;
    @XmlElement(name = "ALLOCATEDPARTQUANTITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY allocatedpartquantity;
    @XmlElement(name = "PARTCONDITIONTEMPLATECONDITIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String partconditiontemplateconditioncode;
    @XmlElement(name = "RETURNCONDITIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String returnconditioncode;
    @XmlElement(name = "DIRECT", required = true)
    protected String direct;
    @XmlAttribute(name = "mlp_recordid")
    protected Long mlp_Recordid;
    @XmlAttribute(name = "res_recordid")
    protected Long res_Recordid;

    /**
     * Gets the value of the workorderpartid property.
     * 
     * @return
     *     possible object is
     *     {@link WORKORDERPARTID }
     *     
     */
    public WORKORDERPARTID getWORKORDERPARTID() {
        return workorderpartid;
    }

    /**
     * Sets the value of the workorderpartid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WORKORDERPARTID }
     *     
     */
    public void setWORKORDERPARTID(WORKORDERPARTID value) {
        this.workorderpartid = value;
    }

    /**
     * Gets the value of the jobsequence property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getJOBSEQUENCE() {
        return jobsequence;
    }

    /**
     * Sets the value of the jobsequence property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setJOBSEQUENCE(Long value) {
        this.jobsequence = value;
    }

    /**
     * Gets the value of the partid property.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Sets the value of the partid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Gets the value of the storeid property.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getSTOREID() {
        return storeid;
    }

    /**
     * Sets the value of the storeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setSTOREID(STOREID_Type value) {
        this.storeid = value;
    }

    /**
     * Gets the value of the plannedpartquantity property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPLANNEDPARTQUANTITY() {
        return plannedpartquantity;
    }

    /**
     * Sets the value of the plannedpartquantity property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPLANNEDPARTQUANTITY(QUANTITY value) {
        this.plannedpartquantity = value;
    }

    /**
     * Gets the value of the reservedpartquantity property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getRESERVEDPARTQUANTITY() {
        return reservedpartquantity;
    }

    /**
     * Sets the value of the reservedpartquantity property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setRESERVEDPARTQUANTITY(QUANTITY value) {
        this.reservedpartquantity = value;
    }

    /**
     * Gets the value of the allocatedpartquantity property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getALLOCATEDPARTQUANTITY() {
        return allocatedpartquantity;
    }

    /**
     * Sets the value of the allocatedpartquantity property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setALLOCATEDPARTQUANTITY(QUANTITY value) {
        this.allocatedpartquantity = value;
    }

    /**
     * Gets the value of the partconditiontemplateconditioncode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTCONDITIONTEMPLATECONDITIONCODE() {
        return partconditiontemplateconditioncode;
    }

    /**
     * Sets the value of the partconditiontemplateconditioncode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTCONDITIONTEMPLATECONDITIONCODE(String value) {
        this.partconditiontemplateconditioncode = value;
    }

    /**
     * Gets the value of the returnconditioncode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRETURNCONDITIONCODE() {
        return returnconditioncode;
    }

    /**
     * Sets the value of the returnconditioncode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRETURNCONDITIONCODE(String value) {
        this.returnconditioncode = value;
    }

    /**
     * Gets the value of the direct property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDIRECT() {
        return direct;
    }

    /**
     * Sets the value of the direct property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDIRECT(String value) {
        this.direct = value;
    }

    /**
     * Gets the value of the mlp_Recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getMlp_Recordid() {
        return mlp_Recordid;
    }

    /**
     * Sets the value of the mlp_Recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setMlp_Recordid(Long value) {
        this.mlp_Recordid = value;
    }

    /**
     * Gets the value of the res_Recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRes_Recordid() {
        return res_Recordid;
    }

    /**
     * Sets the value of the res_Recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRes_Recordid(Long value) {
        this.res_Recordid = value;
    }

}

==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_entities/workorderpart_001/WorkOrderPart.java <==

package net.datastream.schemas.mp_entities.workorderpart_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.PARTID_Type;
import net.datastream.schemas.mp_fields.STOREID_Type;
import net.datastream.schemas.mp_fields.WORKORDERPARTID;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERPARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBSEQUENCE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOREID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PLANNEDPARTQUANTITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RESERVEDPARTQUANTITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ALLOCATEDPARTQUANTITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTCONDITIONTEMPLATECONDITIONCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RETURNCONDITIONCODE" minOccurs="0"/>
 *         &lt;element name="DIRECT" type="{http://schemas.datastream.net/MP_fields}FLAG_Type"/>
 *       &lt;/sequence>
 *       &lt;attribute name="mlp_recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *       &lt;attribute name="res_recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "workorderpartid",
    "jobsequence",
    "partid",
    "storeid",
    "plannedpartquantity",
    "reservedpartquantity",
    "allocatedpartquantity",
    "partconditiontemplateconditioncode",
    "returnconditioncode",
    "direct"
})
@XmlRootElement(name = "WorkOrderPart")
public class WorkOrderPart {

    @XmlElement(name = "WORKORDERPARTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected WORKORDERPARTID workorderpartid;
    @XmlElement(name = "JOBSEQUENCE", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long jobsequence;
    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected PARTID_Type partid;
    @XmlElement(name = "STOREID", namespace = "http://schemas.datastream.net/MP_fields")
    protected STOREID_Type storeid;
    @XmlElement(name = "PLANNEDPARTQUANTITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY plannedpartquantity;
    @XmlElement(name = "RESERVEDPARTQUANTITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY reservedpartquantity;
    @XmlElement(name = "ALLOCATEDPARTQUANTITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY allocatedpartquantity;
    @XmlElement(name = "PARTCONDITIONTEMPLATECONDITIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String partconditiontemplateconditioncode;
    @XmlElement(name = "RETURNCONDITIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String returnconditioncode;
    @XmlElement(name = "DIRECT", required = true)
    protected String direct;
    @XmlAttribute(name = "mlp_recordid")
    protected Long mlp_Recordid;
    @XmlAttribute(name = "res_recordid")
    protected Long res_Recordid;

    /**
     * Obtient la valeur de la propriété workorderpartid.
     * 
     * @return
     *     possible object is
     *     {@link WORKORDERPARTID }
     *     
     */
    public WORKORDERPARTID getWORKORDERPARTID() {
        return workorderpartid;
    }

    /**
     * Définit la valeur de la propriété workorderpartid.
     * 
     * @param value
     *     allowed object is
     *     {@link WORKORDERPARTID }
     *     
     */
    public void setWORKORDERPARTID(WORKORDERPARTID value) {
        this.workorderpartid = value;
    }

    /**
     * Obtient la valeur de la propriété jobsequence.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getJOBSEQUENCE() {
        return jobsequence;
    }

    /**
     * Définit la valeur de la propriété jobsequence.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setJOBSEQUENCE(Long value) {
        this.jobsequence = value;
    }

    /**
     * Obtient la valeur de la propriété partid.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Définit la valeur de la propriété partid.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Obtient la valeur de la propriété storeid.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getSTOREID() {
        return storeid;
    }

    /**
     * Définit la valeur de la propriété storeid.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setSTOREID(STOREID_Type value) {
        this.storeid = value;
    }

    /**
     * Obtient la valeur de la propriété plannedpartquantity.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPLANNEDPARTQUANTITY() {
        return plannedpartquantity;
    }

    /**
     * Définit la valeur de la propriété plannedpartquantity.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPLANNEDPARTQUANTITY(QUANTITY value) {
        this.plannedpartquantity = value;
    }

    /**
     * Obtient la valeur de la propriété reservedpartquantity.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getRESERVEDPARTQUANTITY() {
        return reservedpartquantity;
    }

    /**
     * Définit la valeur de la propriété reservedpartquantity.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setRESERVEDPARTQUANTITY(QUANTITY value) {
        this.reservedpartquantity = value;
    }

    /**
     * Obtient la valeur de la propriété allocatedpartquantity.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getALLOCATEDPARTQUANTITY() {
        return allocatedpartquantity;
    }

    /**
     * Définit la valeur de la propriété allocatedpartquantity.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setALLOCATEDPARTQUANTITY(QUANTITY value) {
        this.allocatedpartquantity = value;
    }

    /**
     * Obtient la valeur de la propriété partconditiontemplateconditioncode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTCONDITIONTEMPLATECONDITIONCODE() {
        return partconditiontemplateconditioncode;
    }

    /**
     * Définit la valeur de la propriété partconditiontemplateconditioncode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTCONDITIONTEMPLATECONDITIONCODE(String value) {
        this.partconditiontemplateconditioncode = value;
    }

    /**
     * Obtient la valeur de la propriété returnconditioncode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRETURNCONDITIONCODE() {
        return returnconditioncode;
    }

    /**
     * Définit la valeur de la propriété returnconditioncode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRETURNCONDITIONCODE(String value) {
        this.returnconditioncode = value;
    }

    /**
     * Obtient la valeur de la propriété direct.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDIRECT() {
        return direct;
    }

    /**
     * Définit la valeur de la propriété direct.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDIRECT(String value) {
        this.direct = value;
    }

    /**
     * Obtient la valeur de la propriété mlp_Recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getMlp_Recordid() {
        return mlp_Recordid;
    }

    /**
     * Définit la valeur de la propriété mlp_Recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setMlp_Recordid(Long value) {
        this.mlp_Recordid = value;
    }

    /**
     * Obtient la valeur de la propriété res_Recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRes_Recordid() {
        return res_Recordid;
    }

    /**
     * Définit la valeur de la propriété res_Recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRes_Recordid(Long value) {
        this.res_Recordid = value;
    }

}
